==> probe_basic-0.2.2.tar.gz: probe_basic-0.2.2/README.md <==
![](probe_basic/images/probe_basic_icon.png)


## Documentation

**probe_basic development installation** https://kcjengr.github.io/probe_basic/dev_install.html

**QtPyVCP use documentation** https://kcjengr.github.io/qtpyvcp/


## Resources

* [Development](https://github.com/kcjengr/ProbeBasic/)
* [Documentation](https://kcjengr.github.io/probe_basic/)
* [Freenode IRC](http://webchat.freenode.net/?channels=%23hazzy) (#hazzy)
* [The Matrix](https://riot.im/app/#/room/#qtpyvcp:matrix.org) (#qtpyvcp:matrix.org)
* [Gitter](https://gitter.im/kcjengr/qtpyvcp)
* [Discord](https://discord.gg/463hMhd)
* [Issue Tracker](https://github.com/kcjengr/ProbeBasic/issues)


## Dependencies

* [LinuxCNC](https://linuxcnc.org)
* Python 2.7
* PyQt5 or PySide2
* [QtPyVCP](https://qtpyvcp.kcjengr.com/)

Probe Basic is developed and tested using the LinuxCNC Debian 9 x64 (stretch)
[Live ISO](http://www.linuxcnc.org/testing-stretch-rtpreempt/) and Ubuntu 18.10 x64 SIM. It should run
on any system that can have PyQt5 installed, but Debian 9 x64 is the only OS
that is officially supported.


## DISCLAIMER

THE AUTHORS OF THIS SOFTWARE ACCEPT ABSOLUTELY NO LIABILITY FOR
ANY HARM OR LOSS RESULTING FROM ITS USE.  IT IS _EXTREMELY_ UNWISE
TO RELY ON SOFTWARE ALONE FOR SAFETY.  Any machinery capable of
harming persons must have provisions for completely removing power
from all motors, etc, before persons enter any danger area.  All
machinery must be designed to comply with local and national safety
codes, and the authors of this software can not, and do not, take
any responsibility for such compliance.

This software is released under the GPLv2.

==> probe_basic-0.3.2.tar.gz: probe_basic-0.3.2/README.md <==
![](probe_basic/images/probe_basic_icon.png)


## Documentation

### installation

https://kcjengr.github.io/probe_basic/quick_start.html

### Development installation 

https://kcjengr.github.io/probe_basic/dev_install.html

### QtPyVCP use documentation

https://qtpyvcp.com


## Resources

* [Development](https://github.com/kcjengr/Probe_Basic/)
* [Documentation](https://kcjengr.github.io/probe_basic/)
* [Freenode IRC](http://webchat.freenode.net/?channels=%23hazzy) (#hazzy) (isolated)
* [The Matrix](https://riot.im/app/#/room/#qtpyvcp:matrix.org) (#qtpyvcp:matrix.org) (bridged)
* [Gitter](https://gitter.im/kcjengr/qtpyvcp) (bridged)
* [Discord](https://discord.gg/463hMhd) (bridged)
* [Issue Tracker](https://github.com/kcjengr/Probe_Basic/issues)


## Dependencies

* [LinuxCNC](https://linuxcnc.org)
* Python 2.7
* PyQt5 or PySide2
* [QtPyVCP](https://qtpyvcp.com/)

Probe Basic is developed and tested using the LinuxCNC Debian 9 x64 (stretch)
[Live ISO](http://www.linuxcnc.org/testing-stretch-rtpreempt/) and Ubuntu 18.10 x64 SIM. It should run
on any system that can have PyQt5 installed, but Debian 9 x64 is the only OS
that is officially supported.


## DISCLAIMER

THE AUTHORS OF THIS SOFTWARE ACCEPT ABSOLUTELY NO LIABILITY FOR
ANY HARM OR LOSS RESULTING FROM ITS USE.  IT IS _EXTREMELY_ UNWISE
TO RELY ON SOFTWARE ALONE FOR SAFETY.  Any machinery capable of
harming persons must have provisions for completely removing power
from all motors, etc, before persons enter any danger area.  All
machinery must be designed to comply with local and national safety
codes, and the authors of this software can not, and do not, take
any responsibility for such compliance.

This software is released under the GPLv2.
